summaryrefslogtreecommitdiff
path: root/run-clang-format.sh
diff options
context:
space:
mode:
authorArchez <Archez@users.noreply.github.com>2025-04-03 23:33:35 -0400
committerGitHub <noreply@github.com>2025-04-03 23:33:35 -0400
commitf37c3aa2286dca72584cf3f2b3d89d0a9f5433e8 (patch)
tree24ce8e47a91d35d2e6c10a88da20761290bc5565 /run-clang-format.sh
parent2deea6e1055a3074a1edcdc6a1d952d544fcf8b1 (diff)
clang-format .hpp files (#5307)
* Add hpp files to clang-format script * clang-format hpp files
Diffstat (limited to 'run-clang-format.sh')
-rwxr-xr-xrun-clang-format.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/run-clang-format.sh b/run-clang-format.sh
index b3a8ae040..20129e63d 100755
--- a/run-clang-format.sh
+++ b/run-clang-format.sh
@@ -10,8 +10,8 @@
# -name "*.c" -o -name "*.cpp"
# find all .c and .cpp files
#
# -name "*.h" ! -path "soh/src/**.h" ! -path "soh/include/**.h"
# find all .h files that aren't in soh/src or soh/include
# this is because zret decomp only runs clang-format on c files
# https://github.com/zeldaret/mm/blob/b7e5468ca16315a7e322055eff3d97fe980bbc25/format.py#L182
#
@@ -26,4 +26,4 @@
# and pass it as an argument to clang-format
# verbose to print files being formatted and X out of Y status
-find soh -type f \( -name "*.c" -o -name "*.cpp" -o \( -name "*.h" ! -path "soh/src/**.h" ! -path "soh/include/**.h" \) \) ! -path "soh/assets/*" -print0 | xargs -0 clang-format-14 -i --verbose
+find soh -type f \( -name "*.c" -o -name "*.cpp" -o \( \( -name "*.h" -o -name "*.hpp" \) ! -path "soh/src/*" ! -path "soh/include/*" \) \) ! -path "soh/assets/*" -print0 | xargs -0 clang-format-14 -i --verbose
@@ -10,8 +10,8 @@
# find all .c and .cpp files
#
-# -name "*.h" ! -path "soh/src/**.h" ! -path "soh/include/**.h"
-# find all .h files that aren't in soh/src or soh/include
+# ( -name "*.h" -o -name "*.hpp" ) ! -path "soh/src/**.h" ! -path "soh/include/**.h"
+# find all .h and .hpp files that aren't in soh/src or soh/include
# this is because zret decomp only runs clang-format on c files
# https://github.com/zeldaret/mm/blob/b7e5468ca16315a7e322055eff3d97fe980bbc25/format.py#L182